document.addEventListener('DOMContentLoaded', () => {
  // Smooth scroll for navigation links
  document.querySelectorAll('a[href^="#"]').forEach(anchor => {
    anchor.addEventListener('click', function (e) {
      e.preventDefault();
      document.querySelector(this.getAttribute('href')).scrollIntoView({
        behavior: 'smooth'
      });
    });
  });

  // Simulated tracking data
  const worlds = ['Decentraland', 'The Sandbox', 'Cryptovoxels', 'Somnium Space'];
  let currentWorldIndex = 0;
  let seconds = 0;
  let distance = 0;

  // Update dashboard stats
  setInterval(() => {
    seconds++;
    distance += Math.random() * 0.1;
    
    document.getElementById('currentWorld').textContent = worlds[currentWorldIndex];
    document.getElementById('timeSpent').textContent = new Date(seconds * 1000).toISOString().substr(11, 8);
    document.getElementById('distance').textContent = distance.toFixed(1) + ' km';
    
    if (Math.random() < 0.1) {
      currentWorldIndex = (currentWorldIndex + 1) % worlds.length;
    }
  }, 1000);

  // Animation for tracking map
  const trackingMap = document.getElementById('trackingMap');
  let hue = 0;

  function animateMap() {
    hue = (hue + 1) % 360;
    trackingMap.style.boxShadow = `0 0 50px hsla(${hue}, 70%, 50%, 0.2)`;
    requestAnimationFrame(animateMap);
  }

  animateMap();

  // Intersection Observer for fade-in animations
  const observer = new IntersectionObserver((entries) => {
    entries.forEach(entry => {
      if (entry.isIntersecting) {
        entry.target.style.opacity = '1';
        entry.target.style.transform = 'translateY(0)';
      }
    });
  });

  document.querySelectorAll('.feature-card').forEach(card => {
    card.style.opacity = '0';
    card.style.transform = 'translateY(20px)';
    card.style.transition = 'opacity 0.5s ease, transform 0.5s ease';
    observer.observe(card);
  });
});
